==> vais_speech-0.0.6.tar.gz: android/src/main/java/tsyliveaudiorecord/live_audio_record/VaisSpeechService.java <==
package tsyliveaudiorecord.live_audio_record;

import android.Manifest;
import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.Intent;
import android.graphics.Color;
import android.media.AudioRecord;
import android.os.Binder;
import android.os.Build;
import android.os.IBinder;
import android.util.Log;

import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.core.app.NotificationCompat;
import androidx.core.content.ContextCompat;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;

import java.io.FileOutputStream;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Locale;
import java.util.Queue;

import io.reactivex.disposables.Disposable;
import io.reactivex.functions.Consumer;

public class VaisSpeechService extends Service {

    private NotificationManager mNotificationManager;

    private ServiceBinder mIBinder;
    private boolean mIsClientBound = false;


    private static final byte RECORDER_BPP = 16; // we use 16bit
    private int mSampleRate = 16000; // 16Khz
    private AudioRecord mRecorder = null;
    private String mFilePath;
    private String mExtension;
    private int bufferSize = 1024;
    private FileOutputStream mFileOutputStream = null;
    private String mStatus = "unset";
    private double mPeakPower = -120;
    private double mAveragePower = -120;
    private Thread mRecordingThread = null;
    private long mDataSize = 0;
    private byte[] tempByteBuffer;
    Queue<HashMap<String, Object>> qe = new LinkedList();



    @Override public IBinder onBind(Intent intent) {
        mIsClientBound = true;
        return mIBinder;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        Log.d("kiemtra","hello");
        mIBinder = new ServiceBinder();

        mNotificationManager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);

    }



    @Override public int onStartCommand(Intent intent, int flags, int startId) {
        HashMap<String, Object> result = (HashMap<String, Object>) intent.getSerializableExtra("result");
        Log.d("kiemtra",result.toString());


        return START_NOT_STICKY;
    }
    @RequiresApi(Build.VERSION_CODES.O)
    private String createNotificationChannel(String channelId, String channelName){
        NotificationChannel chan = new NotificationChannel(channelId,
                channelName, NotificationManager.IMPORTANCE_NONE);
        chan.setLightColor(Color.BLUE);
        chan.setLockscreenVisibility(Notification.VISIBILITY_PRIVATE);
        mNotificationManager.createNotificationChannel(chan);
        return channelId;
    }


    @Override public void onDestroy() {
        super.onDestroy();

    }







    public class ServiceBinder extends Binder {
        public VaisSpeechService getService() {
            return VaisSpeechService.this;
        }
    }

    private PendingIntent getActionIntent(String action) {
        Intent pauseIntent = new Intent(this, AudioRecordService.class);
        pauseIntent.setAction(action);
        return PendingIntent.getService(this, 100, pauseIntent, 0);
    }

    @Override public boolean onUnbind(Intent intent) {
        mIsClientBound = false;
        return true;
    }

    @Override public void onRebind(Intent intent) {
        mIsClientBound = true;
    }
}

==> vais_speech-1.0.8.tar.gz: android/src/main/java/tsyliveaudiorecord/live_audio_record/VaisSpeechService.java <==
package tsyliveaudiorecord.live_audio_record;

import android.Manifest;
import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.Intent;
import android.graphics.Color;
import android.media.AudioRecord;
import android.os.Binder;
import android.os.Build;
import android.os.IBinder;
import android.util.Log;

import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.core.app.NotificationCompat;
import androidx.core.content.ContextCompat;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;

import java.io.FileOutputStream;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.Locale;
import java.util.Queue;

import io.reactivex.disposables.Disposable;
import io.reactivex.functions.Consumer;

public class VaisSpeechService extends Service {

    private NotificationManager mNotificationManager;

    private ServiceBinder mIBinder;
    private boolean mIsClientBound = false;


    private static final byte RECORDER_BPP = 16; // we use 16bit
    private int mSampleRate = 16000; // 16Khz
    private AudioRecord mRecorder = null;
    private String mFilePath;
    private String mExtension;
    private int bufferSize = 1024;
    private FileOutputStream mFileOutputStream = null;
    private String mStatus = "unset";
    private double mPeakPower = -120;
    private double mAveragePower = -120;
    private Thread mRecordingThread = null;
    private long mDataSize = 0;
    private byte[] tempByteBuffer;
    Queue<HashMap<String, Object>> qe;



    @Override public IBinder onBind(Intent intent) {
        mIsClientBound = true;
        return mIBinder;
    }

    @Override
    public void onCreate() {
        super.onCreate();
        Log.d("kiemtra","hello onCreate");
        mIBinder = new ServiceBinder();
        qe = new LinkedList();
        mNotificationManager = (NotificationManager) getSystemService(Context.NOTIFICATION_SERVICE);

    }



    @Override public int onStartCommand(Intent intent, int flags, int startId) {
        HashMap<String, Object> result = (HashMap<String, Object>) intent.getSerializableExtra("result");
        Log.d("kiemtra",result.toString());


        return START_NOT_STICKY;
    }
    @RequiresApi(Build.VERSION_CODES.O)
    private String createNotificationChannel(String channelId, String channelName){
        NotificationChannel chan = new NotificationChannel(channelId,
                channelName, NotificationManager.IMPORTANCE_NONE);
        chan.setLightColor(Color.BLUE);
        chan.setLockscreenVisibility(Notification.VISIBILITY_PRIVATE);
        mNotificationManager.createNotificationChannel(chan);
        return channelId;
    }


    @Override public void onDestroy() {
        super.onDestroy();
        Log.d("kiemtra","onDestroy");
    }








    public class ServiceBinder extends Binder {
        public VaisSpeechService getService() {
            return VaisSpeechService.this;
        }
    }

    private PendingIntent getActionIntent(String action) {
        Intent pauseIntent = new Intent(this, AudioRecordService.class);
        pauseIntent.setAction(action);
        return PendingIntent.getService(this, 100, pauseIntent, 0);
    }

    @Override public boolean onUnbind(Intent intent) {
        mIsClientBound = false;
        return true;
    }

    @Override public void onRebind(Intent intent) {
        mIsClientBound = true;
    }
}
